<?php
/*
  ****************************************************************************
  ***                                                                      ***
  ***      ViArt Shop Enterprise 2.7.1                                     ***
  ***      File:  db_postgre.php                                           ***
  ***      Built: Wed Sep 20 13:19:51 2006                                 ***
  ***      http://www.viart.com                                            ***
  ***                                                                      ***
  ****************************************************************************
*/


class VA_SQL {

  var $DBHost         = "";
  var $DBPort         = "";
  var $DBDatabase     = "";
  var $DBUser         = "";
  var $DBPassword     = "";
  var $DBPersistent   = false;

	/* dates formats */
	var $DatetimeMask   = array("YYYY","-","MM","-","DD"," ","HH",":","mm",":","ss","GMT");
	var $DateMask       = array("YYYY","-","MM","-","DD");
	var $TimeMask       = array("HH",":","mm",":","ss");
	var $TimestampMask  = array("YYYY","MM","DD","HH","mm","ss");

  var $AutoFree       = 0; 
  var $LinkID         = 0;
  var $QueryID        = 0;
  var $PageNumber     = 0;
  var $RecordsPerPage = 0;
  var $Record         = array();
  var $Row            = 0;

  var $Errno       = 0;
  var $Error       = "";
  var $HaltOnError = "yes"; // "yes", "no", "report"

  function VA_SQL($query = "") {
		$this->RecordsPerPage = 0;
		$this->query($query);
  }

  function check_lib() {
		return function_exists ("pg_connect");
	}

  function connect() {
    if (!$this->LinkID) {

      $conn  = "dbname=".$this->DBDatabase;
			$conn .= ($this->DBHost ? " host=" . $this->DBHost : "");
			$conn .= ($this->DBPort ? " port=" . $this->DBPort : "");
			$conn .= ($this->DBUser ? " user=" . $this->DBUser : "");
			$conn .= ($this->DBPassword ? " password=" . $this->DBPassword : "");

      if ($this->DBPersistent)
        $this->LinkID = pg_pconnect($conn);
      else
        $this->LinkID = pg_connect($conn);

      if (!$this->LinkID) {
        $this->halt("Connect failed.");
				return 0;
      }
    }
		return $this->LinkID;
  }

  function query($Query_String) {
    if ($Query_String == "") {
      return 0;
		}

    $this->connect();

		if ($this->RecordsPerPage && $this->PageNumber) {
			$Query_String .= " LIMIT " . $this->RecordsPerPage . " OFFSET " . (($this->PageNumber - 1) * $this->RecordsPerPage);
			$this->RecordsPerPage = 0;
			$this->PageNumber = 0;
		}

    $this->QueryID = @pg_Exec($this->LinkID, $Query_String);
    $this->Row   = 0;

    $this->Error = pg_ErrorMessage($this->LinkID);
    $this->Errno = ($this->Error == "") ? 0 : 1;
    if (!$this->QueryID) {
      $this->halt("Invalid SQL: ".$Query_String);
    }

    return $this->QueryID;
  }
  
  function next_record() {
    $this->Record = @pg_fetch_array($this->QueryID, $this->Row++);
    
    $this->Error = pg_ErrorMessage($this->LinkID);
    $this->Errno = ($this->Error == "") ? 0 : 1;

    $stat = is_array($this->Record);
    if (!$stat && $this->AutoFree) {
      pg_freeresult($this->QueryID);
      $this->QueryID = 0;
    }
    return $stat;
  }

  function seek($pos) {
    $this->Row = $pos;
  }

  function lock($table, $mode = "write") {
    if ($mode == "write") {
      $result = pg_Exec($this->LinkID, "lock table $table");
    } else {
      $result = 1;
    }
    return $result;
  }
  
  function unlock() {
    return pg_Exec($this->LinkID, "commit");
  }

  function affected_rows() {
    return pg_cmdtuples($this->QueryID);
  }

  function num_rows() {
    return pg_numrows($this->QueryID);
  }

  function num_fields() {
    return pg_numfields($this->QueryID);
  }

  function f($Name, $field_type = TEXT) 
	{
    if(isset($this->Record[$Name]))
		{
			$value = $this->Record[$Name];
			switch($field_type)
			{
				case DATETIME:
					$value = parse_date($this->DatetimeMask, $value);
					break;
				case DATE:
					$value = parse_date($this->DateMask, $value);
					break;
				case TIME:
					$value = parse_date($this->TimeMask, $value);
					break;
			}
      return $value; 
		}
    else 
      return "";
  }

  function free_result() {
    @pg_freeresult($this->QueryID);
    $this->QueryID = 0;
  }

  function close()
  {
    if ($this->QueryID) {
      $this->free_result();
    }
    if ($this->LinkID != 0 && !$this->DBPersistent) {
      pg_close($this->LinkID);
      $this->LinkID = 0;
    }
  }  

  
  function halt($msg) {
		if (!$this->Error) { $this->Error = $message; }

    if ($this->HaltOnError == "no") { return; }

		print "<b>Database error:</b> " . $message . "<br>" . CRLF;
		print "<b>PostgreSQL Error Message:</b> " . $this->Error . "<br>" . CRLF;

    if ($this->HaltOnError != "report") {
      die("Session halted.");
		}
  }

	function tosql($value, $value_type, $is_delimiters = true, $use_null = true)
	{
    if(is_array($value) || strlen($value)) 
		{
			switch($value_type)
			{
				case NUMBER:
				case FLOAT:
	        return doubleval(str_replace("," , ".", $value));
					break;
				case TEXT:
					$value = addslashes($value);
					break;
				case DATETIME:
					if(!is_array($value) && is_int($value)) { $value = va_time($value); }
					if(is_array($value)) { $value = va_date($this->DatetimeMask, $value); }
					else { return "NULL"; }
					break;
				case INTEGER:
	        return intval($value);
					break;
				case DATE:
					if(!is_array($value) && is_int($value)) { $value = va_time($value); }
					if(is_array($value)) { $value = va_date($this->DateMask, $value); }
					else { return "NULL"; }
					break;
				case TIME:
					if(!is_array($value) && is_int($value)) { $value = va_time($value); }
					if(is_array($value)) { $value = va_date($this->TimeMask, $value); }
					else { return "NULL"; }
					break;
				case TIMESTAMP:
					if(!is_array($value) && is_int($value)) { $value = va_time($value); }
					if(is_array($value)) { $value = va_date($this->TimestampMask, $value); }
					else { return "NULL"; }
					break;
			}
			if($is_delimiters) {
				$value = "'" . $value . "'";
			}
		} 
		else if($use_null) 
		{
			$value = "NULL";
		} 
		else 
		{
			if($value_type == INTEGER || $value_type == FLOAT || $value_type == NUMBER) {
				$value = 0;
			} else if ($is_delimiters) {
				$value = "''";
			}
		} 
		return $value;
	}


}
?>